<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2011 Jürgen Reinhold <jreinhold@freenet.de>
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/


/**
 *
 *
 * @package du_ranking
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License, version 3 or later
 *
 */
class Tx_DuRanking_Domain_Model_RankingPosition extends Tx_DuRanking_Domain_Model_Positions {

	/**
	 * the number of tournaments this perticipant has played
	 *
	 * @var int
	 */
	protected $tournamentCount;
	
	/**
	 * the number of locations this perticipant has played in
	 *
	 * @var int
	 */
	protected $locationCount;

	/**
	 * the point average. Points per Tournament
	 *
	 * @var int
	 */
	protected $average;

	/**
	 * is participant qualified for the final tournament?
	 *
	 * @var boolean
	 */
	protected $isQualified = False;
	
	/**
	 * __construct
	 *
	 * @param Tx_DuRanking_Domain_Model_Person $participant
	 * @param int $points
	 * @return void
	 */
	public function __construct(Tx_DuRanking_Domain_Model_Person $participant, $points) {
		parent::setParticipant($participant);
		parent::setPoints($points);
		$this->setTournamentCount(1);
		$this->setLocationCount(1);
	}

 	/** 
 	 * Statische Vergleichsfunktion von Platzierungen in der Rangliste
 	 * Hhere Punktzahl ist vorne
 	 * Bei Punkt-Gleichheit ist die Platzierung mit weniger Turnieren vorne
 	 * 
 	 * @return 0 => Gleichheit, -1 => Obj. $a ist besser als Obj. $b, +1 => Obj. $a ist schlechter als Obj. $b
 	 * */
    public static function comparePoints($a, $b)
    {
    	$pointsA = $a->getPoints();
    	$pointsB = $b->getPoints();
        
        if ($pointsA == $pointsB) {
        	$tcountA = $a->getTournamentCount();
        	$tcountB = $b->getTournamentCount();
        	if ($tcountA == $tcountB) {
            	return 0;
        	}
        	else {
        		return ($tcountA < $tcountB) ? -1 : +1;
        	}
        }
        return ($pointsA > $pointsB) ? -1 : +1;
    }
    
	/** 
 	 * Statische Vergleichsfunktion von Platzierungen in der Rangliste
 	 * Hhere Durchschnitt ist vorne
 	 * Noch kein Schnitt vorhanden => hhere Punktzahl ist vorne
 	 * 
 	 * @return 0 => Gleichheit, -1 => Obj. $a ist besser als Obj. $b, +1 => Obj. $a ist schlechter als Obj. $b
 	 * */
    public static function compareAverage($a, $b)
    {
    	$averageA = $a->getAverage();
    	$averageB = $b->getAverage();
        
        if ($averageA == $averageB) {
        	$pointsA = $a->getPoints();
    		$pointsB = $b->getPoints();
    		if ($pointsA == $pointsB) {
    			return 0;
    		}
    		else {
    			return ($pointsA > $pointsB) ? -1 : +1;
    		}
        }
        return ($averageA > $averageB) ? -1 : +1;
    }
    
	/**
	 * Returns the number of tournaments
	 *
	 * @return int
	 */
	public function getTournamentCount() {
		return $this->tournamentCount;
	}
	
	/**
	 * Sets the number of tournaments
	 *
	 * @param int $tournamentCount
	 * @return void
	 */
	public function setTournamentCount($tournamentCount) {
		$this->tournamentCount = $tournamentCount;
	}
	
	/**
	 * Returns the number of locations
	 *
	 * @return int
	 */
	public function getLocationCount() {
		return $this->locationCount;
	}
	
	/**
	 * Sets the number of locations
	 *
	 * @param int $locationCount
	 * @return void
	 */
	public function setLocationCount($locationCount) {
		$this->locationCount = $locationCount;
	}
	
	/**
	 * Returns the average
	 *
	 * @return int $average
	 */
	public function getAverage() {
		return $this->average;
	}

	/**
	 * Sets the average
	 *
	 * @param int $average
	 * @return void
	 */
	public function setAverage($average) {
		$this->average = $average;
	}

	/**
	 * Returns isQualified
	 *
	 * @return boolean $isQualified
	 */
	public function isQualified() {
		return $this->isQualified;
	}

	/**
	 * Sets isQualified
	 *
	 * @param boolean $isQualified
	 * @return void
	 */
	public function setIsQualified($isQualified) {
		$this->isQualified = $isQualified;
	}

}
?>