<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2011 Jürgen Reinhold <jreinhold@freenet.de>
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/


/**
 *
 *
 * @package du_ranking
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License, version 3 or later
 *
 */
class Tx_DuRanking_Domain_Model_Tournament extends Tx_Extbase_DomainObject_AbstractEntity {

	/**
	 * tournamentDate
	 *
	 * @var DateTime
	 * @validate NotEmpty
	 */
	protected $tournamentDate;

	/**
	 * positions
	 *
	 * @var Tx_Extbase_Persistence_ObjectStorage<Tx_DuRanking_Domain_Model_Positions>
	 */
	protected $positions;

	/**
	 * season
	 *
	 * @var Tx_DuRanking_Domain_Model_Season
	 */
	protected $season;

	/**
	 * location
	 *
	 * @var Tx_DuRanking_Domain_Model_Location
	 */
	protected $location;

	/**
	 * manager
	 *
	 * @var Tx_DuRanking_Domain_Model_Person
	 */
	protected $manager;

	
	/**
	 * notice (e.g. best lady, high finish...)
	 *
	 * @var string
	 */
	protected $notice;
	
	/**
	 * __construct
	 *
	 * @return void
	 */
	public function __construct() {
		//Do not remove the next line: It would break the functionality
		$this->initStorageObjects();
	}

	/**
	 * Initializes all Tx_Extbase_Persistence_ObjectStorage properties.
	 *
	 * @return void
	 */
	protected function initStorageObjects() {
		/**
		 * Do not modify this method!
		 * It will be rewritten on each save in the extension builder
		 * You may modify the constructor of this class instead
		 */
		$this->positions = new Tx_Extbase_Persistence_ObjectStorage();
	}

	/**
	 * Returns the tournamentDate
	 *
	 * @return DateTime $tournamentDate
	 */
	public function getTournamentDate() {
		return $this->tournamentDate;
	}

	/**
	 * Sets the tournamentDate
	 *
	 * @param DateTime $tournamentDate
	 * @return void
	 */
	public function setTournamentDate($tournamentDate) {
		$this->tournamentDate = $tournamentDate;
	}

	/**
	 * Adds a Positions
	 *
	 * @param Tx_DuRanking_Domain_Model_Positions $position
	 * @return void
	 */
	public function addPosition(Tx_DuRanking_Domain_Model_Positions $position) {
		$this->positions->attach($position);
	}

	/**
	 * Removes a Positions
	 *
	 * @param Tx_DuRanking_Domain_Model_Positions $positionToRemove The Positions to be removed
	 * @return void
	 */
	public function removePosition(Tx_DuRanking_Domain_Model_Positions $positionToRemove) {
		$this->positions->detach($positionToRemove);
	}

	/**
	 * Returns the positions
	 *
	 * @return Tx_Extbase_Persistence_ObjectStorage<Tx_DuRanking_Domain_Model_Positions> $positions
	 */
	public function getPositions() {
		return $this->positions;
	}

	/**
	 * Sets the positions
	 *
	 * @param Tx_Extbase_Persistence_ObjectStorage<Tx_DuRanking_Domain_Model_Positions> $positions
	 * @return void
	 */
	public function setPositions(Tx_Extbase_Persistence_ObjectStorage $positions) {
		$this->positions = $positions;
	}

	/**
	 * Returns the title (date - location) of the tournament
	 * (Liefert: Datum - Spielsttte)
	 *
	 * @return string
	 */
	public function getTitle() {
		$datum = $this->tournamentDate->format('d.m.y');
		return $datum.' - '.$this->location->getName();
	}

	/**
	 * Returns the time when the tournament starts
	 * (Liefert den Turnierbeginn)
	 *
	 * @return string
	 */
	public function getStartTime() {
		return $this->tournamentDate->format('H:i');
	}
	
	/**
	 * Returns the season
	 *
	 * @return Tx_DuRanking_Domain_Model_Season $season
	 */
	public function getSeason() {
		return $this->season;
	}

	/**
	 * Sets the season
	 *
	 * @param Tx_DuRanking_Domain_Model_Season $season
	 * @return void
	 */
	public function setSeason(Tx_DuRanking_Domain_Model_Season $season) {
		$this->season = $season;
	}

	/**
	 * Returns the location
	 *
	 * @return Tx_DuRanking_Domain_Model_Location $location
	 */
	public function getLocation() {
		return $this->location;
	}

	/**
	 * Sets the location
	 *
	 * @param Tx_DuRanking_Domain_Model_Location $location
	 * @return void
	 */
	public function setLocation(Tx_DuRanking_Domain_Model_Location $location) {
		$this->location = $location;
	}

	/**
	 * Returns the manager
	 *
	 * @return Tx_DuRanking_Domain_Model_Person $manager
	 */
	public function getManager() {
		return $this->manager;
	}

	/**
	 * Sets the manager
	 *
	 * @param Tx_DuRanking_Domain_Model_Person $manager
	 * @return void
	 */
	public function setManager(Tx_DuRanking_Domain_Model_Person $manager) {
		$this->manager = $manager;
	}

	/**
	 * Returns the notice
	 *
	 * @return string $notice
	 */
	public function getNotice() {
		return $this->notice;
	}

	/**
	 * Sets the notice
	 *
	 * @param string $notice
	 * @return void
	 */
	public function setNotice(string $notice) {
		$this->notice = $notice;
	}
}
?>